@@ -2,14 +2,14 @@ from enum import Enum
 from typing import Mapping, Union, MutableMapping, Callable
 
 import numpy as np
-import tensorflow as tf
+from tensorflow import Tensor
 
 
 NumericType = Union[int, float]
 PrimitiveType = Union[int, float, str, bool]
 AggregatorType = Callable[..., NumericType]
 MetricKeyType = Union[str, 'Metric']
-MetricValueType = Union[NumericType, np.ndarray, tf.Tensor]
+MetricValueType = Union[NumericType, np.ndarray, Tensor]
 
 
 TRAIN_PREFIX = 'Training'
