@@ -37,5 +37,5 @@ class Mean(Metric):
         return self.mean
 
     def reset_state(self) -> None:
-        self.mean.assign(1, tf.zeros((), self.dtype))
+        self.mean.assign(tf.zeros((), self.dtype))
         self.count.assign(tf.zeros((), self.dtype))
