@@ -162,19 +162,11 @@ class KerasModel(Model, ABC):
             for callback in callbacks:
                 callback.on_epoch_begin(epoch)
 
-            train_metrics = self.convert_metrics(train_dataset(
-                dataset=self.create_tf_dataset(train_batches),
-                loss=self.loss,
-                optimizer=self.optimizer,
-                metrics=metrics,
-            ))
+            train_metrics = self.convert_metrics(train_dataset(train_batches, self.loss, self.optimizer, metrics))
             metric_results = metric_helpers.prefix_metrics_train(train_metrics)
 
             if validation_batches is not None:
-                validation_metrics = self.convert_metrics(test_dataset(
-                    dataset=self.create_tf_dataset(validation_batches),
-                    metrics=metrics,
-                ))
+                validation_metrics = self.convert_metrics(test_dataset(validation_batches, metrics))
                 metric_results.update(metric_helpers.prefix_metrics_validation(validation_metrics))
 
             for callback in callbacks:
@@ -186,10 +178,7 @@ class KerasModel(Model, ABC):
         results = None
 
         if test_batches is not None:
-            test_metrics = self.convert_metrics(test_dataset(
-                dataset=self.create_tf_dataset(test_batches),
-                metrics=metrics,
-            ))
+            test_metrics = self.convert_metrics(test_dataset(test_batches, metrics))
             results = metric_helpers.prefix_metrics_test(test_metrics)
 
         for callback in callbacks:
